#!/usr/bin/env node

var fs = require('fs'),
    mapnik = require('mapnik'),
    path = require('path'),
    optimist = require('optimist'),
    child_process = require('child_process'),
    argv = require('optimist').argv;

var usage = 'usage: overhead --size=600x400 --projection="+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs" <stylesheet> <image>';

var merc_proj4 = '+proj=merc +a=6378137 +b=6378137 +lat_ts=0.0 +lon_0=0.0 +x_0=0.0 +y_0=0 +k=1.0 +units=m +nadgrids=@null +wktext +no_defs +over';

argv.proj4 = argv.proj4 || merc_proj4;

var projobj = new mapnik.Projection(argv.proj4);

try {
    var stylesheet = fs.readFileSync(argv._[0], 'utf-8');
    if (argv.proj4) {
        stylesheet = stylesheet.replace(/Map srs=\"([^"]*)/, function(str, substr) {
            return str.replace(substr, argv.proj4);
        });
    }
} catch(e) {
    console.log(usage);
    process.exit(1);
}

var image = argv._[1];
if (!image) {
   console.log(usage);
   process.exit(1);
}

var x = 600, y = 400;
if (argv.size) {
    x = parseInt(argv.size.split('x')[0]),
    y = parseInt(argv.size.split('x')[1]);
}

function renderMap(stylesheet, image) {
    var map = new mapnik.Map(x, y, argv.proj4 || merc_proj4);
    map.fromStringSync(stylesheet);
    if (argv.bbox) {
        map.zoomToBox(projobj.forward(argv.bbox.split(',')));
    } else {
        map.zoomAll();
    }
    map.renderFileSync(image);
    child_process.exec('open ' + image);
}

renderMap(stylesheet, image);
